
.. py:currentmodule:: pythreejs

BooleanKeyframeTrack
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: BooleanKeyframeTrack(name='', times=None, values=None, interpolation="InterpolateLinear", )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.KeyframeTrack`.

    Three.js docs: https://threejs.org/docs/#api/animation/tracks/BooleanKeyframeTrack


